import request from "@/utils/request";
import { type ResultV1, ResultV4 } from "@/types/request-result";
const UserApi = {
  /**
   * 登录
   * @param name 用户名
   * @param pwd  密码
   */
  login(name: string, pwd: string) {
    return request<any, LoginResult>({
      method: "POST",
      url: "login/login",
      params: {
        name,
        pwd,
      },
    });
  },

  // 安全退出
  logout() {
    return request({
      method: "POST",
      url: "login/logout",
    });
  },

  /**
   * 查询用户-带分页
   * @param pageNum   当前页
   * @param pageSize  每页条数
   */
  search(pageNum: number, pageSize: number) {
    return request<any, ResultV1<UserInfo>>({
      method: "GET",
      url: "user/getPage",
      params: {
        pageNum,
        pageSize,
      },
    });
  },

  /**
   *  添加用户信息
   * @param data
   */
  add(data: UserInfo) {
    return request<any, ResultV4>({
      method: "POST",
      url: "user/add",
      data,
    });
  },

  /**
   *  编辑用户信息
   * @param data
   */
  edit(data: UserInfo) {
    return request<any, ResultV4>({
      method: "POST",
      url: "user/update",
      data,
    });
  },
};

export default UserApi;

/** 登录请求参数 */
export interface LoginFormData {
  /** 用户名 */
  username: string;
  /** 密码 */
  password: string;
  /** 验证码缓存key */
  captchaKey: string;
  /** 验证码 */
  captchaCode: string;
}

/** 登录用户信息 */
export interface UserInfo {
  /** 用户ID */
  id?: number;

  /** 用户名 */
  name?: string;

  /** 密码 */
  pwd?: string;

  /** 性别 */
  sex?: number;

  /** 角色 */
  roleId?: number;

  /** 邮箱 */
  email?: string;

  /** 电话 */
  phoneNumber?: string;

  /** 创建日期 */
  createTime?: string;

  roles: string[];

  perms: string[];
}

/** 登录接口返回 */
export interface LoginResult {
  /** 接口是否调用成功 */
  code: number;

  /** 是否登录成功 */
  data: boolean;

  /** 返回结果 */
  data2?: UserInfo;

  /** 返回提示 */
  msg: string;
}
